# Generated by Django 2.0.1 on 2018-06-23 13:37

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion

from vpnathome.tests import is_running_under_test
from vpnathome.apps.openvpn.utils import generate_dhparams


TEST_DHPARAMS = "-----BEGIN DH PARAMETERS-----\n"\
                "MCYCIQCZRsh+9KB+NQA6sDHCEyhCUgNcEx4cz7P6ale/UpygWwIBAg==\n"\
                "-----END DH PARAMETERS-----"

def create_dhparams(apps, schema_editor):
    DhParams = apps.get_model('openvpn', 'DhParams')
    if not is_running_under_test():
        generated_dhparams = generate_dhparams()
        DhParams.objects.create(dhparams=generated_dhparams)
    else:
        DhParams.objects.create(dhparams=TEST_DHPARAMS)

class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('x509', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Client',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('name', models.CharField(max_length=64)),
                ('cert', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='x509.Cert')),
                ('owner', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='DhParams',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dhparams', models.TextField(blank=True, default='', max_length=4096)),
            ],
        ),
        migrations.CreateModel(
            name='Server',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('name', models.CharField(max_length=64)),
                ('hostname', models.CharField(max_length=128)),
                ('tls_auth_key', models.CharField(max_length=8192)),
                ('protocol', models.CharField(choices=[('udp', 'UDP'), ('tcp', 'TCP')], default='udp', max_length=10)),
                ('ca', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='x509.Ca')),
                ('cert', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='x509.Cert')),
                ('dhparams', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='openvpn.DhParams')),
                ('owner', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (('download_server_config', 'Download server config'),),
            },
        ),
        migrations.AddField(
            model_name='client',
            name='server',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='openvpn.Server'),
        ),
        migrations.RunPython(create_dhparams)
    ]
